@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
 //
-// SPDX-License-Identifier: LGPL-3.0-or-later
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef NETWORKDEVICEBASE_H
 #define NETWORKDEVICEBASE_H
@@ -22,10 +22,7 @@ class NetworkDeviceBase : public QObject
 {
     Q_OBJECT
 
-    friend class NetworkController;
-    friend class NetworkInterProcesser;
-    friend class NetworkManagerProcesser;
-    friend class IPConfilctChecker;
+    friend class ObjectManager;
 
     Q_PROPERTY(QString statusName READ getStatusName)
     Q_PROPERTY(QString statusDetail READ statusStringDetail)                                    // 当前状态详细说明，取代statusStringDetail接口
@@ -45,45 +42,47 @@ class NetworkDeviceBase : public QObject
     Q_PROPERTY(QStringList ipv4 READ ipv4)                                                      // 对应于ipv4接口
     Q_PROPERTY(QStringList ipv6 READ ipv6)                                                      // 对应于ipv6接口
     Q_PROPERTY(QString deviceName READ deviceName WRITE setName NOTIFY nameChanged)             // 对应于设备名称
+    Q_PROPERTY(bool available READ available)                                                   // 设备是否可用(对应于interfaceFlags是否大于0)
 
 Q_SIGNALS:
-    void deviceStatusChanged(const DeviceStatus &) const;                                        // 状态发生变化的时候触发的信号
-    void enableChanged(const bool) const;                                                        // 开启设备或禁用设备的时候发出的信号(参数值True表示开启设备，False表示禁用设备)
+    void deviceStatusChanged(const DeviceStatus &);                                              // 状态发生变化的时候触发的信号
+    void enableChanged(const bool);                                                              // 开启设备或禁用设备的时候发出的信号(参数值True表示开启设备，False表示禁用设备)
     void connectionChanged();                                                                    // 连接发生变化的时候触发的信号
     void nameChanged(const QString &);                                                           // 网卡名称发生变化的时候触发的信号
     void removed();                                                                              // 设备移除
     void activeConnectionChanged();                                                              // 活动连接发生变化的时候发出的信号
     void ipV4Changed();                                                                          // IPV4地址变化
+    void availableChanged(bool);                                                                 // 设备是否可用
 
 public:
     bool isEnabled() const;                                                                      // 当前的网卡是否启用
+    bool available() const;                                                                      // 设备是否可用
     virtual bool isConnected() const = 0;                                                        // 当前网络的网络是否处于连接状态
     bool IPValid();                                                                              // IP是否合法
     virtual DeviceType deviceType() const = 0;                                                   // 设备类型 未识别 无线网卡 有线网卡，直接在子类中返回当前的类型即可
     DeviceStatus deviceStatus() const;                                                           // 设备状态
-    QString interface() const;               // 返回设备上的Interface
-    QString driver() const;                  // 驱动，对应于备上返回值的Driver
-    bool managed() const;                    // 对应于设备上返回值的Managed
-    QString vendor() const;                  // 对应于设备上返回值的Vendor
-    QString uniqueUuid() const;             // 网络设备的唯一的UUID，对应于设备上返回值的UniqueUuid
-    bool usbDevice() const;                 // 是否是USB设备，对应于设备上返回值的UsbDevice
-    QString path() const;                   // 设备路径，对应于设备上返回值的Path
-    QString activeAp() const;               // 对应于设备上返回值的ActiveAp
-    bool supportHotspot() const;           // 是否支持热点,对应于设备上返回值的SupportHotspot
-    QString realHwAdr() const;             // mac地址
-    QString usingHwAdr() const;           // 正在使用的mac地址
-    QStringList ipv4() const;                                                                        // IPV4地址
-    QStringList ipv6() const;                                                                        // IPV6地址
-    QJsonObject activeConnectionInfo() const;                                                    // 获取当前活动连接的信息
+    QString interface() const;                                                                   // 返回设备上的Interface
+    QString driver() const;                                                                      // 驱动，对应于备上返回值的Driver
+    bool managed() const;                                                                        // 对应于设备上返回值的Managed
+    QString vendor() const;                                                                      // 对应于设备上返回值的Vendor
+    QString uniqueUuid() const;                                                                  // 网络设备的唯一的UUID，对应于设备上返回值的UniqueUuid
+    bool usbDevice() const;                                                                      // 是否是USB设备，对应于设备上返回值的UsbDevice
+    QString path() const;                                                                        // 设备路径，对应于设备上返回值的Path
+    QString activeAp() const;                                                                    // 对应于设备上返回值的ActiveAp
+    bool supportHotspot() const;                                                                 // 是否支持热点,对应于设备上返回值的SupportHotspot
+    QString realHwAdr() const;                                                                   // mac地址
+    QString usingHwAdr() const;                                                                  // 正在使用的mac地址
+    QStringList ipv4() const;                                                                    // IPV4地址
+    QStringList ipv6() const;                                                                    // IPV6地址
     void setEnabled(bool enabled);                                                               // 开启或禁用网卡
-    void disconnectNetwork();                                                        // 断开网络连接，该方法是一个虚方法，具体在子类
-    Connectivity connectivity();
+    void disconnectNetwork();                                                                    // 断开网络连接，该方法是一个虚方法，具体在子类
+    bool ipConflicted();
     virtual void setName(const QString &name);                                                   // 设置设备的名称
     virtual QString deviceName();                                                                // 设备名称
 
 protected:
     explicit NetworkDeviceBase(NetworkDeviceRealize *deviceInter, QObject *parent = Q_NULLPTR);
-    virtual ~NetworkDeviceBase();
+    ~NetworkDeviceBase() override;
     NetworkDeviceRealize *deviceRealize() const;
     void enqueueStatus(const DeviceStatus &status);
     virtual bool getHotspotEnabeld() { return false; }
@@ -103,4 +102,4 @@ private:
 
 }
 
-#endif // UNETWORKDEVICEBASE_H
+#endif  // NETWORKDEVICEBASE_H
